@@ -27,7 +27,43 @@ from .scope_in import ScopeIn
 from .scope_out import ScopeOut
 from .scope_update import ScopeUpdate
 from .token import Token
+from .upload_out import UploadOut
 from .user_in import UserIn
 from .user_out import UserOut
 from .user_update import UserUpdate
 from .validation_error import ValidationError
+
+__all__ = (
+    "BaseError",
+    "BodyLoginForAccessToken",
+    "BodyRefreshToken",
+    "CollectionDatasetOut",
+    "CollectionIn",
+    "CollectionOut",
+    "CollectionUpdate",
+    "DatasetIn",
+    "DatasetInMeta",
+    "DatasetMeta",
+    "DatasetMetaKeys",
+    "DatasetMetaMeta",
+    "DatasetOut",
+    "DatasetOutMeta",
+    "DatasetUpdate",
+    "FileDatasetIn",
+    "FileDatasetOut",
+    "FileIn",
+    "FileOut",
+    "FileStatus",
+    "FileType",
+    "FileUpdate",
+    "HTTPValidationError",
+    "ScopeIn",
+    "ScopeOut",
+    "ScopeUpdate",
+    "Token",
+    "UploadOut",
+    "UserIn",
+    "UserOut",
+    "UserUpdate",
+    "ValidationError",
+)
