@@ -1,8 +1,10 @@
-from typing import Any, Dict, List, Type, TypeVar
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar
 
 import attr
 
-from ..models.dataset_meta_meta import DatasetMetaMeta
+if TYPE_CHECKING:
+    from ..models.dataset_meta_meta import DatasetMetaMeta
+
 
 T = TypeVar("T", bound="DatasetMeta")
 
@@ -14,7 +16,7 @@ class DatasetMeta:
         meta (DatasetMetaMeta):
     """
 
-    meta: DatasetMetaMeta
+    meta: "DatasetMetaMeta"
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -32,6 +34,8 @@ class DatasetMeta:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.dataset_meta_meta import DatasetMetaMeta
+
         d = src_dict.copy()
         meta = DatasetMetaMeta.from_dict(d.pop("meta"))
 
