@@ -18,31 +18,37 @@ class FileDatasetOut:
         name (str):
         uid (str):
         status (FileStatus): An enumeration.
+        collected (Union[Unset, datetime.datetime]):
+        duration (Union[Unset, float]):
         creator (Union[Unset, str]):
         etag (Union[Unset, str]):
         size (Union[Unset, int]):
         mimetype (Union[Unset, str]):  Default: 'application/octet-stream'.
         altlocation (Union[Unset, str]):
         rating (Union[Unset, int]):
-        immutable (Union[Unset, bool]):  Default: True.
-        filetype (Union[Unset, FileType]): An enumeration.
+        immutable (Union[Unset, bool]):
+        filetype (Union[Unset, FileType]): An enumeration. Default: FileType.UNDEFINED.
         created (Union[Unset, datetime.datetime]):
         modified (Union[Unset, datetime.datetime]):
+        download_link (Union[Unset, str]):
     """
 
     name: str
     uid: str
     status: FileStatus
+    collected: Union[Unset, datetime.datetime] = UNSET
+    duration: Union[Unset, float] = UNSET
     creator: Union[Unset, str] = UNSET
     etag: Union[Unset, str] = UNSET
     size: Union[Unset, int] = UNSET
     mimetype: Union[Unset, str] = "application/octet-stream"
     altlocation: Union[Unset, str] = UNSET
     rating: Union[Unset, int] = 0
-    immutable: Union[Unset, bool] = True
-    filetype: Union[Unset, FileType] = UNSET
+    immutable: Union[Unset, bool] = False
+    filetype: Union[Unset, FileType] = FileType.UNDEFINED
     created: Union[Unset, datetime.datetime] = UNSET
     modified: Union[Unset, datetime.datetime] = UNSET
+    download_link: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -50,6 +56,11 @@ class FileDatasetOut:
         uid = self.uid
         status = self.status.value
 
+        collected: Union[Unset, str] = UNSET
+        if not isinstance(self.collected, Unset):
+            collected = self.collected.isoformat()
+
+        duration = self.duration
         creator = self.creator
         etag = self.etag
         size = self.size
@@ -59,10 +70,7 @@ class FileDatasetOut:
         immutable = self.immutable
         filetype: Union[Unset, str] = UNSET
         if not isinstance(self.filetype, Unset):
-            if self.filetype:
-                filetype = self.filetype.value
-            else:
-                filetype = None
+            filetype = self.filetype.value
 
         created: Union[Unset, str] = UNSET
         if not isinstance(self.created, Unset):
@@ -72,6 +80,8 @@ class FileDatasetOut:
         if not isinstance(self.modified, Unset):
             modified = self.modified.isoformat()
 
+        download_link = self.download_link
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -81,6 +91,10 @@ class FileDatasetOut:
                 "status": status,
             }
         )
+        if collected is not UNSET:
+            field_dict["collected"] = collected
+        if duration is not UNSET:
+            field_dict["duration"] = duration
         if creator is not UNSET:
             field_dict["creator"] = creator
         if etag is not UNSET:
@@ -101,6 +115,8 @@ class FileDatasetOut:
             field_dict["created"] = created
         if modified is not UNSET:
             field_dict["modified"] = modified
+        if download_link is not UNSET:
+            field_dict["download_link"] = download_link
 
         return field_dict
 
@@ -113,6 +129,15 @@ class FileDatasetOut:
 
         status = FileStatus(d.pop("status"))
 
+        _collected = d.pop("collected", UNSET)
+        collected: Union[Unset, datetime.datetime]
+        if isinstance(_collected, Unset):
+            collected = UNSET
+        else:
+            collected = isoparse(_collected)
+
+        duration = d.pop("duration", UNSET)
+
         creator = d.pop("creator", UNSET)
 
         etag = d.pop("etag", UNSET)
@@ -132,7 +157,7 @@ class FileDatasetOut:
         if isinstance(_filetype, Unset):
             filetype = UNSET
         else:
-            filetype = FileType(_filetype) if _filetype else None
+            filetype = FileType(_filetype)
 
         _created = d.pop("created", UNSET)
         created: Union[Unset, datetime.datetime]
@@ -148,10 +173,14 @@ class FileDatasetOut:
         else:
             modified = isoparse(_modified)
 
+        download_link = d.pop("download_link", UNSET)
+
         file_dataset_out = cls(
             name=name,
             uid=uid,
             status=status,
+            collected=collected,
+            duration=duration,
             creator=creator,
             etag=etag,
             size=size,
@@ -162,6 +191,7 @@ class FileDatasetOut:
             filetype=filetype,
             created=created,
             modified=modified,
+            download_link=download_link,
         )
 
         file_dataset_out.additional_properties = d
